@@ -70,6 +70,8 @@ class DownloadableFileSchema(BaseSchema):
 
     file_ext = fields.Str(dump_only=True)
     data_category = fields.Str(dump_only=True)
+    data_category_prefix = fields.Str(dump_only=True)
+    cimac_id = fields.Str(dump_only=True)
 
 
 DownloadableFileListSchema = _make_list_schema(DownloadableFileSchema())
@@ -87,5 +89,7 @@ class TrialMetadataSchema(BaseSchema):
     class Meta(BaseSchema.Meta):
         model = TrialMetadata
 
+    file_bundle = fields.Dict(dump_only=True)
+
 
 TrialMetadataListSchema = _make_list_schema(TrialMetadataSchema())
